local BaikCore = LibStub("AceAddon-3.0"):GetAddon("BaikCore")
local SharedMedia = LibStub("LibSharedMedia-3.0")
local Assert = BaikCore.Assert
local Database = BaikCore.Database
local Option = BaikCore.Option

-- Add Module
local StatusBar = BaikCore:NewModule("StatusBar")
BaikCore.StatusBar = StatusBar

-- Constants
local MEDIA_TYPE = SharedMedia.MediaType.STATUSBAR
local DEFAULT = SharedMedia:GetDefault(MEDIA_TYPE)
StatusBar.GLOBAL = GLOBAL
StatusBar.DEFAULT = DEFAULT

local function GetOpts()
end

-- Private Variables
local statusbars = {}

-- Private Methods
local function StatusBarName(category)
    Assert:String(category)

    return Database:Get(category)
end

local function StatusBarTexture(category)
    local name = StatusBarName(category)

    return SharedMedia:Fetch(MEDIA_TYPE, name)
end

-- StatusBar API
function StatusBar:AddBar(bar, category)
    Assert:String(category)

    if not statusbars[category] then
        statusbars[category] = {}
    end

    table.insert(statusbars[category], bar)
end

function StatusBar:AddBars(barTable, category)
    Assert:Table(barTable)
    Assert:String(category)

    if not statusbars[category] then
        statusbars[category] = {}
    end

    for _, bar in pairs(barTable) do
        table.insert(statusbars[category], bar)
    end
end

function StatusBar:ClearBars(category)
    statusbars[category] = {}
end

function StatusBar:SyncCategory(category)
    Assert:String(category)
    Assert:NotNull(statusbars[category])

    local barTexture = StatusBarTexture(category)
    for _, statusbar in pairs(statusbars[category]) do
        if statusbar then
            statusbar:SetStatusBarTexture(barTexture)
        end
    end
end

function StatusBar:GetOpts(optName, dbValue)
    Assert:String(optName)
    return {
        name = optName,
        type = "group",
        args = {
            texture = {
                name = "Texture",
                type = "select",
                dialogControl = "LSM30_Statusbar",
                values = AceGUIWidgetLSMlists.statusbar,
                get = function(...)
                    return Database:Get(dbValue)
                end,
                set = function(self, value, ...)
                    Database:Set(dbValue, value)
                    StatusBar:SyncCategory(dbValue)
                end
            }
        }
    }
end

-- Ace3 Callbacks
function StatusBar:OnInitialize()
end

function StatusBar:OnEnable()
end

function StatusBar:OnDisable()
end
